Description Usage Arguments Value
This function takes an RZA .xlxs dataframe and will make either individual plots of each RZA taxa group or two faceted maps based on 150 and 500 micron mesh. The maps plot abundance per cubic meter of the rza taxa for each station. The map regions are standardized for each of the major cruises/grids for EcoFOCI.
1 | make_rza_plots(rza_path, region, facets = TRUE)
|
rza_path |
The path to the directory where the .xlxs rza dataframe is located along with the .xlxs file name. This is a dataframe specifically formated for rza data entry. |
region |
There are six geographic regions which produce standardized maps. The six standardized maps can be set to Arctic, Northern BS, 70 meter, BASIS, GOA, and MACE 2018. |
facets |
By default facets is set to TRUE. When set to TRUE the function will produce two sets of faceted maps. One of the 60 bongo rza taxa and one of the 20 bongo rza taxa. When facets is set to FALSE the function will produce a map for each rza taxa. |
Either faceted maps or individual maps of rza taxa abundance.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.